package de.fhw.swtprojekt.knauf.gridbaglayout;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.JDialog;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

/**Dialog mit insgesamt 6 TextAreas in zwei Spalten und drei Zeilen, die
 * den verfgbaren Platz gleichmig aufteilen.
 * Layout:
 *      TextArea1  TextArea2
 *      TextArea3  TextArea4
 *      TextArea5  TextArea5
 * 
 * 
 * @author Wolfgang Knauf
 *
 */
public class DialogMultiTextAreas extends JDialog
{
  /**SerialVersionUID muss sein, da Basisklasse serialisierbar.
   */
  private static final long serialVersionUID = 1L;

  /**Konstruktor initialisiert den Dialog.
   * 
   */
  public DialogMultiTextAreas()
  {
    this.setSize(300, 300);
    this.setTitle("2*3 TextAreas");
    //Wichtig: ein Dialog ist Modal!
    this.setModal(true);
    
    GridBagLayout gridBayLayout = new GridBagLayout();
    this.setLayout(gridBayLayout);
    
    //Ein TextArea zufgen. Damit das Scrollbar ist, kommt es auf ein JScrollPane.
    JScrollPane scrollPane1 = new JScrollPane();
    scrollPane1.setName("scrollPane1");
    
    //Es kommt in Zelle 0/0 und ersteckt sich ber eine Spalte. 
    //In x-Richtung bekommt es 50% des verfgbaren Platzes, in y-Richtung 33%.
    //Hier kann man statt einer Angabe "0.33" auch einen beliebigen Zahlenwert nehmen,
    //der mit den anderen Y-Faktoren aller Controls der gleichen Spalte addiert wird und 
    //relativ zu diesem gesetzt wird. Drei Controls mit einer y-weigth von "1" ergeben in der Summe 3,
    //also bekommt jede Komponente ein Drittel.
    gridBayLayout.setConstraints(scrollPane1, new GridBagConstraints (0, 0, 1, 1, 2, 1, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0 ));
    this.add(scrollPane1);
    
    //In das ScrollPane kommt ein TextArea:
    JTextArea textArea1 = new JTextArea();
    textArea1.setText("TextArea 1");
    textArea1.setName("textArea1");
    scrollPane1.getViewport().add(textArea1);
    
    
    JScrollPane scrollPane2 = new JScrollPane();
    scrollPane2.setName("scrollPane2");
    //Es kommt in Zelle 1/0 und ersteckt sich ber eine Spalte. 
    gridBayLayout.setConstraints(scrollPane2, new GridBagConstraints (1, 0, 1, 1, 1, 1, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0 ));
    this.add(scrollPane2);
    JTextArea textArea2 = new JTextArea();
    textArea2.setText("TextArea 2");
    textArea2.setName("textArea2");
    scrollPane2.getViewport().add(textArea2);
    
    
    JScrollPane scrollPane3 = new JScrollPane();
    scrollPane3.setName("scrollPane3");
    //Es kommt in Zelle 0/1 und ersteckt sich ber eine Spalte. 
    gridBayLayout.setConstraints(scrollPane3, new GridBagConstraints (0, 1, 1, 1, 2, 2, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0 ));
    this.add(scrollPane3);
    JTextArea textArea3 = new JTextArea();
    textArea3.setText("TextArea 3");
    textArea3.setName("textArea3");
    scrollPane3.getViewport().add(textArea3);
    
    JScrollPane scrollPane4 = new JScrollPane();
    scrollPane4.setName("scrollPane4");
    //Es kommt in Zelle 1/1 und ersteckt sich ber eine Spalte. 
    gridBayLayout.setConstraints(scrollPane4, new GridBagConstraints (1, 1, 1, 1, 1, 2, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0 ));
    this.add(scrollPane4);
    JTextArea textArea4 = new JTextArea();
    textArea4.setText("TextArea 4");
    textArea4.setName("textArea4");
    scrollPane4.getViewport().add(textArea4);
    
    JScrollPane scrollPane5 = new JScrollPane();
    scrollPane5.setName("scrollPane5");
    //Es kommt in Zelle 0/2 und ersteckt sich ber eine Spalte. 
    gridBayLayout.setConstraints(scrollPane5, new GridBagConstraints (0, 2, 1, 1, 2, 1, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0 ));
    this.add(scrollPane5);
    JTextArea textArea5 = new JTextArea();
    textArea5.setText("TextArea 5");
    textArea5.setName("textArea5");
    scrollPane5.getViewport().add(textArea5);
    
    JScrollPane scrollPane6 = new JScrollPane();
    scrollPane6.setName("scrollPane6");
    //Es kommt in Zelle 2/1 und ersteckt sich ber eine Spalte. 
    gridBayLayout.setConstraints(scrollPane6, new GridBagConstraints (1, 2, 1, 1, 1, 1, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0 ));
    this.add(scrollPane6);
    JTextArea textArea6 = new JTextArea();
    textArea6.setText("TextArea 6");
    textArea6.setName("textArea6");
    scrollPane6.getViewport().add(textArea6);
  }
}