package de.fhw.swtprojekt.knauf.gridbaglayout;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

/**Dialog mit einen TextArea, das ber fast die ganze Dialoggre geht,
 * sich den Platz aber mit zwei Buttons teilt.
 * Layout:
 *      TextAreaTextArea
 *      Button1   Button2
 * TextArea geht ber zwei Spalten, Buttons darunter.
 * 
 * @author Wolfgang Knauf
 *
 */
public class DialogTextAreaButtons extends JDialog
{
  /**SerialVersionUID muss sein, da Basisklasse serialisierbar.
   */
  private static final long serialVersionUID = 1L;

  /**Konstruktor initialisiert den Dialog.
   * 
   */
  public DialogTextAreaButtons()
  {
    this.setSize(300, 300);
    this.setTitle("TextArea mit zwei Buttons");
    //Wichtig: ein Dialog ist Modal!
    this.setModal(true);
    
    GridBagLayout gridBayLayout = new GridBagLayout();
    this.setLayout(gridBayLayout);
    
    //Ein TextArea zufgen. Damit das Scrollbar ist, kommt es auf ein JScrollPane.
    JScrollPane scrollPane = new JScrollPane();
    scrollPane.setName("scrollPane");
    
    //Es kommt in Zelle 0/0 und ersteckt sich ber zwei Spalten, soll in x- und y-Richtung den verfgbaren freien Platz einnehmen.
    gridBayLayout.setConstraints(scrollPane, new GridBagConstraints (0, 0, 2, 1, 1.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0 ));
    this.add(scrollPane);
    
    //In das ScrollPane kommt ein TextArea:
    JTextArea textArea = new JTextArea();
    textArea.setName("textArea");
    scrollPane.getViewport().add(textArea);
    
    //Und darunter kommen zwei Buttons (die diesmal nix machen):
    JButton button1 = new JButton ("Button 1");
    button1.setName("button1");
    //Der Button ist in Tabellenzelle 0/1 (Zeile 1, Spalte 0), erstreckt sich ber eine Zelle,
    //und soll sich nicht resizen.
    //Er soll sich den verfgbaren Bereich mit Button 2 zu 50% teilen.
    gridBayLayout.setConstraints(button1, new GridBagConstraints (0, 1, 1, 1, 0.5, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE,  new Insets(0, 0, 0, 0), 0, 0 ));
    this.add(button1);
    
    JButton button2 = new JButton ("Button 2");
    button2.setName("button2");
    //Der Button ist in Tabellenzelle 1/1 (Zeile 1, Spalte 1), erstreckt sich ber eine Zelle,
    //und soll sich nicht resizen.
    //Er soll sich den verfgbaren Bereich mit Button 2 zu 50% teilen.
    gridBayLayout.setConstraints(button2, new GridBagConstraints (1, 1, 1, 1, 0.5, 0.0, GridBagConstraints.CENTER, GridBagConstraints.NONE,  new Insets(0, 0, 0, 0), 0, 0 ));
    this.add(button2);
  }

}
